Python utilities for analyzing telescope pointing performance
-------------------------------------------------------------

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. image:: https://github.com/MMTObservatory/pytelpoint/workflows/CI%20Tests/badge.svg
    :target: https://github.com/MMTObservatory/pytelpoint/actions
    :alt: CI Tests status

.. image:: https://codecov.io/gh/MMTObservatory/pytelpoint/branch/main/graph/badge.svg?token=SV8E0QZ9XI
    :target: https://codecov.io/gh/MMTObservatory/pytelpoint
    :alt: Code coverage status

.. image:: https://readthedocs.org/projects/pytelpoint/badge/?version=latest
    :target: https://pytelpoint.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

License
-------

This project is Copyright (c) MMTO Observatory and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause license. See the licenses folder for
more information.
